<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Autohide idle time</source>
        <translation>Tiempo de inactividad antes de ocultarse automáticamente</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n segundo</numerusform><numerusform>%n segundos</numerusform></translation>
    </message>
    <message>
        <source>Buddies list</source>
        <translation>Lista de contactos</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Buddies window</source>
        <translation>Ventana de contactos</translation>
    </message>
    <message>
        <source>Hide buddy list window when unused</source>
        <translation>Ocultar la ventana con la lista de contactos cuando no se utilice</translation>
    </message>
</context>
<context>
    <name>AutoHideConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t hide</source>
        <translation>No ocultar</translation>
    </message>
</context>
</TS>